@@ -94,6 +94,7 @@ usWords<-function(text){
 #' @return character Vector of clean strings.
 #' @keywords internal
 cleanpunct<-function(text){
+  text=unlist(lapply(text, noLeadDash))
   # text<-gsub("‘", "'",text)
   # text<-gsub("’", "'", text)
   # text<-gsub("“", '"', text)
@@ -107,3 +108,14 @@ cleanpunct<-function(text){
   text<-stringi::stri_trans_general(text, "latin-ascii")
   return(text)
 }
+
+#' Cleaning leading punctuation
+#' @description Handles interruption dashes.
+#' @param text character Vector of strings to clean.
+#' @return character Vector of clean strings.
+#' @keywords internal
+noLeadDash<-function(text){
+  tLoc<-gregexpr("[[:alpha:]]",text)[[1]]
+  text=substr(text,tLoc,nchar(text))
+  return(text)
+}
